package ppx_minidebug

  1. Overview
  2. Docs

Module type Minidebug_runtime.Debug_runtime_condSource

include Debug_runtime
Sourceval close_log : unit -> unit
Sourceval open_log_preamble_brief : fname:string -> pos_lnum:int -> pos_colnum:int -> message:string -> unit
Sourceval open_log_preamble_full : fname:string -> start_lnum:int -> start_colnum:int -> end_lnum:int -> end_colnum:int -> message:string -> unit
Sourceval log_value_sexp : descr:string -> sexp:Sexplib0.Sexp.t -> unit
Sourceval log_value_pp : descr:string -> pp:(Format.formatter -> 'a -> unit) -> v:'a -> unit
Sourceval log_value_show : descr:string -> v:string -> unit
Sourceval exceeds_max_nesting : unit -> bool
Sourceval exceeds_max_children : unit -> bool
Sourceval no_debug_if : bool -> unit

When passed true within the scope of a log subtree, disables the logging of this subtree and its subtrees. Does not do anything when passed false (no_debug_if false does not re-enable the log).